<?php

namespace frontend\modules\retails\controllers;

use Yii;
use frontend\modules\retails\models\Stores;
use frontend\modules\retails\models\SearchStores;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use frontend\modules\retails\models\StoresHistory;
use yii\filters\AccessControl;
use frontend\modules\retails\models\Ledger;
/**
 * StoresController implements the CRUD actions for Stores model.
 */
class StoresController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
           'access' => [
            'class' => AccessControl::className(),
            'rules' => [
                [
                    'allow' => true,
                    'actions' => ['view','findModel','itemdetails'],
                    'roles' => ['@'],
                ],
                  [
                    'allow' => true,
                    'actions' => ['sledger','index','create','update','movement'],
                    'roles' => ['Store Manager','Client Admin'],
                ],
                 [
                    'allow' => true,
                    'actions' => ['sledger','delete','create','update','fix'],
                    'roles' => ['Client Admin'],
                ],
                    ],
                ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Stores models.
     * @return mixed
     */
    public function actionIndex()
    {
        // if(Yii::$app->user->identity->role!='Client Admin')
        // {
        //     die('You are not allowed to do this');
        // }
        
        $searchModel = new SearchStores();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Stores model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Stores model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Stores();

        //  if(Yii::$app->user->identity->role!='Client Admin')
        // {
        //     die('You are not allowed to do this');
        // }

        

        if ($model->load(Yii::$app->request->post()) && $model->validate()) {

            $transaction = Yii::$app->db->beginTransaction();
        try {


            $model->transaction_id=time().rand(10,20);
            $model->name=ucwords($model->name);
            $model->balance=$model->quantity; 
            $model->issued_by=Yii::$app->user->identity->id;         

            if(!$model->save())
            {
                // var_dump($model->getErrors()); die;
                 throw new \Exception( 'could not save to store' );  
            }

            // enter into store history

                    if($model->countable==1){
                    $storeh=new StoresHistory();
                    $storeh->name=$model->name;
                    $storeh->cid=Yii::$app->user->identity->cid;
                    $storeh->units=$model->units;
                    $storeh->standing_quantity=0;
                    $storeh->particulars=$model->particulars;
                   // $storeh->received_date=date('Y-m-d');
                    // $storeh->recieved_by=$uti->recieved_by;
                    $storeh->recieved_by=Yii::$app->user->identity->id;
                    $storeh->transaction_id='fresh'.date('Y-m-d');
                    $storeh->balance=$model->quantity;
                    $storeh->transaction_quantity=$model->quantity;
                    $storeh->issued_date=date('Y-m-d');
                    $storeh->description=$model->particulars;
                    $storeh->vendor=0;
                    $storeh->type=12;
                    $storeh->qin=$model->quantity;
                    
                    $storeh->issued_by=Yii::$app->user->identity->id;
                    $storeh->given_to=Yii::$app->user->identity->id;
                    $storeh->item_id=$model->id;
                    if(!$storeh->save())
                        {
                            throw new \Exception('could not save to store' ); 
                            // var_dump($storeh->getErrors()); die;
                        }
                    }


                   
                    $transaction->commit();

                    } catch (\Exception $e) {
                        $transaction->rollBack();
                        throw $e; die('failed');
                    } catch (\Throwable $e) {
                        $transaction->rollBack();
                        throw $e; die('failed');
                    }


            return $this->redirect(['view', 'id' => $model->id]);
            }
        

        return $this->render('create', [
            'model' => $model,
        ]);
    }

    /**
     * Updates an existing Stores model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        //  if(Yii::$app->user->identity->role!='Client Admin')
        // {
        //     die('You are not allowed to do this');
        // }
        $model = $this->findModel($id);
        $keep=$model->quantity;

        if ($model->load(Yii::$app->request->post())) {
            $model->name=ucwords($model->name);
            $model->quantity=$keep;
            $model->issued_by=Yii::$app->user->identity->id;


            $model->save();
            return $this->redirect(['view', 'id' => $model->id]);
        }

        return $this->render('update', [
            'model' => $model,
        ]);
    }

    /**
     * Deletes an existing Stores model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        die('no going');
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Stores model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Stores the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Stores::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }

    public function actionSledger()
    {
        $records=Stores::find()->where(['=','cid',Yii::$app->user->identity->cid])->andWhere(['!=','countable',2])->all();
        return $this->render('sledger',['records'=>$records]);
    }

    public function actionItemdetails($id)
    {
        $history=StoresHistory::find()->where(['=','item_id',$id])->andWhere(['=','cid',Yii::$app->user->identity->cid])->all();
        return $this->render('item_details',['history'=>$history]);
    }

    public function actionMovement()
    {
      
      if(Yii::$app->request->post())
      {      
        $from=Yii::$app->request->post('from');
        $to=Yii::$app->request->post('to');
         $querym="select sum(qin) as qin, sum(qout) as qout, issued_date, item_id, type, transaction_quantity, standing_quantity from stores_history where substr(issued_date,1,10)>='".$from."' and  substr(issued_date,1,10)<='".$to."' and cid='".Yii::$app->user->identity->cid."' group by item_id";
         $bobo = Yii::$app->db->createCommand($querym)->queryAll();

       
          return $this->render('movement',['records'=>$bobo,'datef'=>$from,'tof'=>$to]);
      }else{
      return $this->render('movement');
    }
    }

    public function actionFix()
    {
      $all=StoresHistory::find()->all();
      foreach($all as $a)
      {
        if($a->type==12)
        {
          $a->qin=$a->transaction_quantity;
          $a->save();
        }
        if($a->type==11)
        {
          $a->qout=$a->transaction_quantity;
          $a->save();
        }
      }
    }
}
//  15671821141 // 287 //35